@@ -1,14 +1,13 @@
 import typer
 
 import os, sys
-pwd = "/".join(__file__.split("/")[:-1])
+pwd = "/".join(__file__.split("/")[:-1]) + "/lib"
 sys.path.append(pwd)
-os.system("export PYTHONPATH="+pwd)
 
-import wifi as wifi
-import bt as bt
-import util as util
-import archive as archive
+import lib.wifi as wifi
+import lib.bt as bt
+import lib.util as util
+import lib.archive as archive
 
 
 main_app = typer.Typer()
